==> django-sysace-1.2.1.tar.gz: django-sysace-1.2.1/ace/README.md <==
Django-SysAce - Sistema de Administração de Cabeamento Estruturado e Infraestrutura de TI
=============================================================================

[![Documentation Status](https://readthedocs.org/projects/django-sysace/badge/?version=latest)](http://django-sysace.readthedocs.io/en/latest/?badge=latest)

Sistema desenvolvido em Django para controle de pontos de rede (voz, dados, voip), ramais, telefones, switches, racks, patchpanels, equipamentos, redes, serviços e endereços IP.

O ACE permite um controle centralizado de várias informações da infraestrutura de TI de uma organização  tais como:

* Listagem de todos os servidores, sejam físicos ou virtuais em uso ou não;
* Localização dos equipamentos (computadores, impressoras, switches, accesspoints, equipamentos de segurança e outros);
* Controle de bens;
* Conexões de rede de equipamentos em tomadas, patchpanels e portas de switches;
* Controle de VLANs e suas associações a redes e portas de switch;
* Controle de switches e pilhas (stacks);
* Controle de redes e endereçamentos IP;
* Controle de linhas telefônicas sejam elas analógicas, digitais ou VoIP.


Documentação
------------
Compatível com **Django 1.11**

A documentação está disponível no [Readthedocs](http://django-sysace.readthedocs.io).



Requisitos (Requirements)
------------

- Python 2.7
- Django 1.11



Resources
---------

- [Git graciously hosted](https://github.com/rogeriocdluiz/Django-SysAce) by [GitHub](http://github.com)
- [Documentation graciously hosted](http://django-sysace.readthedocs.io) by [RTFD](http://rtfd.org)
- [Package graciously hosted](https://pypi.python.org/pypi/django-sysace) by [PyPi](http://pypi.python.org/pypi)

==> django-sysace-1.2.3.tar.gz: django-sysace-1.2.3/ace/README.md <==
Django-SysAce - Sistema de Administração de Cabeamento Estruturado e Infraestrutura de TI
=========================================================================================

[![Documentation Status](https://readthedocs.org/projects/django-sysace/badge/?version=latest)](http://django-sysace.readthedocs.io/en/latest/?badge=latest)

Sistema desenvolvido em Django para controle de pontos de rede (voz, dados, voip), ramais, telefones, switches, racks, patchpanels, equipamentos, redes, serviços e endereços IP.

O ACE permite um controle centralizado de várias informações da infraestrutura de TI de uma organização  tais como:

* Listagem de todos os servidores, sejam físicos ou virtuais em uso ou não;
* Localização dos equipamentos (computadores, impressoras, switches, accesspoints, equipamentos de segurança e outros);
* Controle de bens;
* Conexões de rede de equipamentos em tomadas, patchpanels e portas de switches;
* Controle de VLANs e suas associações a redes e portas de switch;
* Controle de switches e pilhas (stacks);
* Controle de redes e endereçamentos IP;
* Controle de linhas telefônicas sejam elas analógicas, digitais ou VoIP.


Documentação
------------
Compatível com **Django 1.11**

A documentação está disponível no [Readthedocs](http://django-sysace.readthedocs.io).



Requisitos (Requirements)
-------------------------

- Python 2.7
- Django 1.11



Resources
---------

- [Git graciously hosted](https://github.com/rogeriocdluiz/Django-SysAce) by [GitHub](http://github.com)
- [Documentation graciously hosted](http://django-sysace.readthedocs.io) by [RTFD](http://rtfd.org)
- [Package graciously hosted](https://pypi.org/project/django-sysace/) by [PyPi](https://pypi.org)
